@@ -24,13 +24,28 @@ MainWindow::MainWindow(QWidget *parent):
 {
     ui->setupUi(this);
 
-    setAttribute(Qt::WA_Maemo5StackedWindow);
+    //Set Window
+    this->setWindowTitle("FlopSwap");
+    this->setAttribute(Qt::WA_Maemo5StackedWindow);
+
+    //Set Button Text
+    ui->pushButtonSwap->setText(tr("Fresh Swap"));
+    ui->pushButtonEject->setText(tr("Swap to Device"));
+    ui->pushButtonGet->setText(tr("Show Current"));
+    ui->pushButtonSwapUsage->setText(tr("Check Status"));
+    //Set Action Text
+    ui->actionSettings->setText(tr("Settings"));
+    ui->actionReadme->setText(tr("Quick Guide"));
+    ui->actionHelp->setText(tr("Help"));
+    ui->actionAbout->setText(tr("About"));
+
+    //Set Actions
     about = new About(this);
     help = new Help(this);
     instructions = new Instructions(this);
     settingspage = new Settings(this);
 
-  // For Connecting Keyboard Buttons
+    //For Connecting Keyboard Buttons
     connectSignals();
 
 }
@@ -98,19 +113,19 @@ void MainWindow::showExpanded()
 #endif
 }
 
-  // Keyboard Button Signals - remember to include QShortcut
+   //Keyboard Button Signals - remember to include QShortcut
 void MainWindow::connectSignals()
 {
 
-  // Keyboard Key Signals
+    //Keyboard Key Signals
     connect(new QShortcut(QKeySequence(Qt::Key_Q), this), SIGNAL(activated()), this, SLOT(on_pushButtonSwap_clicked()));
     connect(new QShortcut(QKeySequence(Qt::Key_W), this), SIGNAL(activated()), this, SLOT(on_pushButtonEject_clicked()));
     connect(new QShortcut(QKeySequence(Qt::Key_A), this), SIGNAL(activated()), this, SLOT(on_pushButtonGet_clicked()));
     connect(new QShortcut(QKeySequence(Qt::Key_S), this), SIGNAL(activated()), this, SLOT(on_pushButtonSwapUsage_clicked()));
 }
 
-  // End of Keyboard Signals
 
+//Buttons
 void MainWindow::on_pushButtonSwap_clicked()
 {
     m_process->start("sudo /opt/flopswap/script/swapswitch.sh");
@@ -131,6 +146,7 @@ void MainWindow::on_pushButtonSwapUsage_clicked()
     m_process->start("sudo /opt/flopswap/script/swapused.sh");
 }
 
+//Actions
 void MainWindow::on_actionAbout_triggered()
 {
     about->show();
